@@ -197,9 +197,9 @@ def add_lib_excludes(key, excludebits):
         config["excludes"][key].extend([f"{name}.lib{exclude}", f"lib{exclude}"])
 
     for exclude in ("32", "64"):
-        for pycompat in ("38", "39", "310"):
+        for pycompat in ("38", "39", "310", "311"):
             if key == "win32" and (
-                pycompat == sys.version[0] + sys.version[2] or exclude == excludebits[0]
+                pycompat == str(sys.version_info[0]) + str(sys.version_info[1]) or exclude == excludebits[0]
             ):
                 continue
             config["excludes"][key].extend(
@@ -308,7 +308,7 @@ def create_app_symlinks(dist_dir, scripts):
                     tgt = os.path.join(toolcontents, entry, subentry)
                     if subentry == "main.py":
                         # py2app
-                        with open(src, "rb") as main_in:
+                        with open(src, "r") as main_in:
                             py = main_in.read()
                         py = py.replace("main()", "main(%r)" % script[len(name) + 1:])
                         with open(tgt, "wb") as main_out:
@@ -478,11 +478,11 @@ def setup():
             pass
         try:
             import setuptools
-            from setuptools import setup, Extension
+            from setuptools import setup, Extension, find_packages
 
             setuptools = True
             print("using setuptools")
-            current_findall = setuptools.findall
+            current_findall = find_packages
         except ImportError:
             pass
     else:
@@ -955,7 +955,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
     packages = [name, f"{name}.lib", f"{name}.lib.agw"]
     if sdist:
         # For source distributions we want all libraries
-        for pycompat in ("38", "39", "310"):
+        for pycompat in ("38", "39", "310", "311"):
             packages.extend(
                 [
                     f"{name}.lib{bits}",
@@ -1265,6 +1265,8 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                     "mswsock.dll",
                     "urlmon.dll",
                     "w9xpopen.exe",
+                    "gdiplus.dll",
+                    "mfc90.dll",
                 ],
                 "excludes": config["excludes"]["all"] + config["excludes"]["win32"],
                 "bundle_files": 3 if wx.VERSION >= (2, 8, 10, 1) else 1,
@@ -1559,8 +1561,8 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                 attrs.get("package_dir", {}).get(pkg, pkg).split("/")
             )
             manifest_in.append("include " + os.path.join(pkgdir, "*.py"))
-            manifest_in.append("include " + os.path.join(pkgdir, "*.pyd"))
-            manifest_in.append("include " + os.path.join(pkgdir, "*.so"))
+            # manifest_in.append("include " + os.path.join(pkgdir, "*.pyd"))
+            # manifest_in.append("include " + os.path.join(pkgdir, "*.so"))
             for obj in attrs.get("package_data", {}).get(pkg, []):
                 manifest_in.append(
                     "include " + os.path.sep.join([pkgdir] + obj.split("/"))
@@ -1624,38 +1626,6 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
         if dry_run or help:
             return
 
-        if do_py2app:
-            frameworks_dir = os.path.join(
-                dist_dir, name + ".app", "Contents", "Frameworks"
-            )
-            lib_dynload_dir = os.path.join(
-                dist_dir,
-                name + ".app",
-                "Contents",
-                "Resources",
-                "lib",
-                "python%s.%s" % sys.version_info[:2],
-                "lib-dynload",
-            )
-            # Fix Pillow (PIL) dylibs not being included
-            pil_dylibs = os.path.join(lib_dynload_dir, "PIL", ".dylibs")
-            if not os.path.isdir(pil_dylibs):
-                import PIL
-
-                pil_installed_dylibs = os.path.join(
-                    os.path.dirname(PIL.__file__), ".dylibs"
-                )
-                print("Copying", pil_installed_dylibs, "->", pil_dylibs)
-                shutil.copytree(pil_installed_dylibs, pil_dylibs)
-                for entry in os.listdir(pil_dylibs):
-                    print(os.path.join(pil_dylibs, entry))
-                # Remove wrongly included frameworks
-                dylibs_entries = os.listdir(pil_installed_dylibs)
-                for entry in os.listdir(frameworks_dir):
-                    if entry in dylibs_entries:
-                        dylib = os.path.join(frameworks_dir, entry)
-                        print("Removing", dylib)
-                        os.remove(dylib)
             import wx
 
             if wx.VERSION >= (4,):
