@@ -30,10 +30,11 @@ if wx.VERSION < wx_minversion:
     app = wx.GetApp() or wx.App(0)
     result = wx.MessageBox(
         "This application requires a version of wxPython "
-        "greater than or equal to %s, but your most recent "
-        "version is %s.\n\n"
-        "Would you like to download a new version of wxPython?\n"
-        % (".".join(str(n) for n in wx_minversion), wx.__version__),
+        "greater than or equal to {}, but your most recent "
+        "version is {}.\n\n"
+        "Would you like to download a new version of wxPython?\n".format(
+            ".".join(str(n) for n in wx_minversion), wx.__version__
+        ),
         "wxPython Upgrade Needed",
         style=wx.YES_NO,
     )
@@ -47,6 +48,7 @@ import wx.grid
 from wx.lib.buttons import GenBitmapButton as _GenBitmapButton
 from wx.lib.buttons import ThemedGenButton as _ThemedGenButton
 from wx.lib.buttons import GenBitmapTextButton as _GenBitmapTextButton
+from wx.lib.scrolledpanel import ScrolledPanel
 from wx.lib import platebtn
 from wx import xrc
 
@@ -1150,6 +1152,7 @@ class ScrolledWindow(wx._ScrolledWindow):
 
 
 wx.ScrolledWindow = ScrolledWindow
+ScrolledPanel.ScrollChildIntoView = ScrolledWindow.ScrollChildIntoView
 
 
 class GenButton(object):
